import { indirectOverride } from './external-reexport';
export { directOverride as renamedDirectOverride } from './external-reexport';

export const renamedIndirectOverride = indirectOverride;
